# actor.py

from entity import Entity


class Actor():
  def __init__(self, name, x, y, color, sprites_l, sprites_r, transp_color):
    self.entity = Entity(name, x, y, sprites_l[0], transp_color)
    #self.entity.draw_x = -(sprites_l[0].get_rect().width>>1)
    #self.entity.draw_y = 1-sprites_l[0].get_rect().height
    
    self.direction = 8
    self.color = color
    self.inventory = []
    self.active_item = None
    
    self.idle_anim = [[sprites_r[0]],[sprites_l[0]]]
    self.walk_anim = [
      [sprites_r[1], sprites_r[2], sprites_r[3], sprites_r[4]],
      [sprites_l[1], sprites_l[2], sprites_l[3], sprites_l[4]]
    ]
    self.talk_anim = [
      [sprites_r[0], sprites_r[5]],
      [sprites_l[0], sprites_l[5]]
    ]
    self.anim_delay = 2
    
    self._active_anim = self.idle_anim
    self._anim_ticks = 0
    
    # Pointer to function to be run when player examines (look at) entity
    self.examine = None
    # Pointer to function to be run when player interacts (use) with entity
    self.interact = None
  
  
  def update(self):
    frames = self._active_anim[int(self.direction > 4)]
    frame_idx = (self._anim_ticks//self.anim_delay)%len(frames)
    self.entity.sprite = frames[frame_idx]
    self._anim_ticks += 1
    
    self.entity.z_order = self.entity.y
  
  
  def start_idle_anim(self):
    self._active_anim = self.idle_anim
    self._anim_ticks = 0
  
  
  def start_walk_anim(self):
    self._active_anim = self.walk_anim
    self._anim_ticks = 0
  
  
  def start_talk_anim(self):
    self._active_anim = self.talk_anim
    self._anim_ticks = 0
  
  
  def find_item(self, entity):
    for idx in range(len(self.inventory)):
      if self.inventory[idx] == entity:
        return idx
    return -1

  
  def add_item(self, entity):
    self.inventory.append(entity)

  
  def remove_item(self, entity):
    for idx in range(len(self.inventory)):
      if self.inventory[idx] == entity:
        self.inventory.pop(idx)
        return

  
  def find_item(self, entity):
    for idx in range(len(self.inventory)):
      if self.inventory[idx] == entity:
        return idx
    return -1

